@@ -110,13 +110,13 @@ if 'odnoklassniki_users' in settings.INSTALLED_APPS:
 #    @opt_generator
     def update_users(self, **kwargs):
         ids = self.__class__.remote.get_members_ids(group=self)
-        # TODO: remove time_from of first updating
-#        initial = self.users.count() == 0
+        first = self.users.versions.count() == 0
 
         self.users = User.remote.fetch(ids=ids)
 
-#         if initial:
-#             self.users.get_query_set_through().update(time_from=None)
+        if first:
+            self.users.get_query_set_through().update(time_from=None)
+            self.users.versions.update(added_count=0)
 
         return self.users.all()
 else:
